{ config, pkgs, lib, ... }:
let
  user = config.yoda.user;
in
{
  # Issue: Login does not work. Webbrowser does not redirect back to Element app. Firefox does not ask to open link with Element app. It works with the Flatpak version though.
  #
  # Configuration paths with user data:
  #   NixOS: /home/${user}/.config/Element /home/${user}/.config/Riot
  #   Flatpak: /home/${user}/.var/app/im.riot.Riot/config/Element
  #
  # Solution: Don't use element-desktop-wayland, use the normal element-desktop package instead
  #
  # Workaround:
  # - Login with Flatpak version
  # - Delete .config/Element and .config/Riot
  # - Copy Flatpak into .config/Element
  # - Start the NixOS version, you should be logged in :D

  # Issue: No visible UI on yodaTux (AMD Ryzen 4800H) when using unstable.element-desktop
  # Workaround: Use Flatpak version ...
  # Discussion on GitHub: https://github.com/NixOS/nixpkgs/issues/343806 AMD GPUs and NixOS - 'Cannot find target for triple amdgcn-- Unable to find target for this triple (no targets are registered)'

  users.users."${user}" = {
    packages = with pkgs; [
      # Matrix chat client.
      element-desktop
    ];
  };
}
